@@ -17,8 +17,8 @@ module Rack
           ret
         end
 
-        def self.split_header_value(str) # From WEBrick::HTTPUtils
-          str.scan(/((?:"(?:\\.|[^"])+?"|[^",]+)+)(?:,\s*|\Z)/n).collect{ |v| v[0] }
+        def self.split_header_value(str)
+          str.scan( /(\w+\=(?:"[^\"]+"|[^,]+))/n ).collect{ |v| v[0] }
         end
 
         def initialize
@@ -35,7 +35,7 @@ module Rack
           super k.to_s, v.to_s
         end
 
-        UNQUOTED = ['qop', 'nc', 'stale']
+        UNQUOTED = ['nc', 'stale']
 
         def to_s
           inject([]) do |parts, (k, v)|
